import * as React from 'react';
import { ItemsSource, Pager as NativeScriptPager, PagerItem as NativeScriptPagerItem } from '../';
import { Orientation } from '../';
import { Template, Color, CoreTypes, View, KeyedTemplate } from '@nativescript/core';
import { NSVElement, ViewAttributes, NativeScriptProps, GridLayoutAttributes } from "react-nativescript";
export declare type PagerAttributes = ViewAttributes & {
    items?: any;
    selectedIndex: number;
    onItemLoading?: (args: any) => void;
    itemIdGenerator?: (item: any, index: number, items: any) => number;
    itemTemplate?: string | Template;
    itemTemplateSelector?: string | ((item: any, index: number, items: any) => string);
    itemTemplates?: string | KeyedTemplate[];
    canGoRight: boolean;
    canGoLeft: boolean;
    spacing: CoreTypes.PercentLengthType | string;
    peaking: CoreTypes.PercentLengthType | string;
    perPage: number;
    orientation: Orientation;
    transformers: string;
    loadMoreCount: number;
    disableSwipe: boolean;
    indicator: any;
    showIndicator: boolean;
    indicatorColor: Color | string;
    indicatorSelectedColor: Color | string;
    ios?: any;
    android?: any;
};
export declare type CellViewContainer = View;
declare type CellFactory = (item: any) => React.ReactElement;
declare type OwnProps = {
    items: ItemsSource | any[];
    /** User may specify cellFactory for single-template or cellFactories for multi-template. */
    cellFactory?: CellFactory;
    cellFactories?: Map<string, {
        placeholderItem: any;
        cellFactory: CellFactory;
    }>;
    onSelectedIndexChange?(args: any): void;
    onSelectedIndexChanged?(args: any): void;
    scroll?(args: any): void;
    swipe?(args: any): void;
    swipeStart?(args: any): void;
    swipeOver?(args: any): void;
    swipeEnd?(args: any): void;
    onLoadMoreItems?: (args: any) => void;
    _debug?: {
        logLevel: "debug" | "info";
        onCellFirstLoad?: (container: CellViewContainer) => void;
        onCellRecycle?: (container: CellViewContainer) => void;
    };
} & Omit<PagerAttributes, "onItemLoading">;
declare type Props = OwnProps & {
    forwardedRef?: React.RefObject<NSVElement<NativeScriptPager>>;
};
declare type NumberKey = number | string;
interface State {
    nativeCells: Record<NumberKey, CellViewContainer>;
    nativeCellToItemIndex: Map<CellViewContainer, NumberKey>;
    itemIndexToNativeCell?: Map<NumberKey, CellViewContainer>;
}
export declare class _Pager extends React.Component<Props, State> {
    static readonly defaultProps: {
        _debug: {
            logLevel: "info";
            onCellFirstLoad: any;
            onCellRecycle: any;
        };
    };
    constructor(props: Props);
    private readonly myRef;
    private readonly argsViewToRootKeyAndRef;
    private roots;
    private readonly defaultOnItemLoading;
    protected getNativeView(): NativeScriptPager | null;
    private readonly renderNewRoot;
    componentDidMount(): void;
    componentWillUnmount(): void;
    static isItemsSource(arr: any[] | ItemsSource): arr is ItemsSource;
    render(): JSX.Element;
}
export declare type PagerItemAttributes = GridLayoutAttributes & {
    forwardedRef?: React.RefObject<NSVElement<NativeScriptPagerItem>>;
};
export declare class _PagerItem extends React.Component<PagerItemAttributes, {}> {
    private readonly myRef;
    private readonly item;
    componentDidMount(): void;
    render(): React.ReactElement<{
        ref: React.RefObject<NSVElement<NativeScriptPagerItem>>;
        left?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        top?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        alignSelf?: "auto" | "stretch" | "flex-start" | "flex-end" | "center" | "baseline";
        android?: any;
        bindingContext?: any;
        class?: string;
        className?: string;
        col?: number;
        colSpan?: number;
        column?: NumberKey;
        columnSpan?: NumberKey;
        cssClasses?: Set<string>;
        cssPseudoClasses?: Set<string>;
        dock?: "left" | "top" | "right" | "bottom";
        domNode?: import("@nativescript/core/debugger/dom-node").DOMNode;
        effectiveBorderBottomWidth?: number;
        effectiveBorderLeftWidth?: number;
        effectiveBorderRightWidth?: number;
        effectiveBorderTopWidth?: number;
        effectiveHeight?: number;
        effectiveLeft?: number;
        effectiveMarginBottom?: number;
        effectiveMarginLeft?: number;
        effectiveMarginRight?: number;
        effectiveMarginTop?: number;
        effectiveMinHeight?: number;
        effectiveMinWidth?: number;
        effectivePaddingBottom?: number;
        effectivePaddingLeft?: number;
        effectivePaddingRight?: number;
        effectivePaddingTop?: number;
        effectiveTop?: number;
        effectiveWidth?: number;
        flexGrow?: number;
        flexShrink?: number;
        flexWrapBefore?: boolean;
        hidden?: string | boolean;
        id?: string;
        ios?: any;
        isCollapsed?: any;
        isLoaded?: boolean;
        nativeView?: any;
        onBindingContextChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onClassNameChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onHiddenChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIdChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        order?: number;
        page?: import("@nativescript/core").Page;
        parent?: import("@nativescript/core").ViewBase;
        parentNode?: import("@nativescript/core").ViewBase;
        recycleNativeView?: "auto" | "always" | "never";
        reusable?: boolean;
        row?: NumberKey;
        rowSpan?: NumberKey;
        typeName?: string;
        viewController?: any;
        accessibilityHidden?: string | boolean;
        accessibilityHint?: string;
        accessibilityIdentifier?: string;
        accessibilityIgnoresInvertColors?: string | boolean;
        accessibilityLabel?: string;
        accessibilityLanguage?: string;
        accessibilityLiveRegion?: import("@nativescript/core").AccessibilityLiveRegion;
        accessibilityMediaSession?: string | boolean;
        accessibilityRole?: import("@nativescript/core").AccessibilityRole;
        accessibilityState?: import("@nativescript/core").AccessibilityState;
        accessibilityValue?: string;
        accessible?: string | boolean;
        androidDynamicElevationOffset?: NumberKey;
        androidElevation?: NumberKey;
        automationText?: string;
        background?: string;
        backgroundColor?: string | Color;
        backgroundImage?: string | import("@nativescript/core/ui/styling/gradient").LinearGradient;
        backgroundPosition?: string;
        backgroundRepeat?: "repeat" | "repeat-x" | "repeat-y" | "no-repeat";
        backgroundSize?: string;
        borderBottomColor?: string | Color;
        borderBottomLeftRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderBottomRightRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderBottomWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderColor?: string | Color;
        borderLeftColor?: string | Color;
        borderLeftWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderRightColor?: string | Color;
        borderRightWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderTopColor?: string | Color;
        borderTopLeftRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderTopRightRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderTopWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        borderWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        boxShadow?: string | import("@nativescript/core/ui/styling/css-shadow").CSSShadow;
        color?: string | Color;
        css?: string;
        cssType?: string;
        height?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        horizontalAlignment?: "left" | "right" | "stretch" | "center";
        iosIgnoreSafeArea?: string | boolean;
        iosOverflowSafeArea?: boolean;
        iosOverflowSafeAreaEnabled?: string | boolean;
        isEnabled?: string | boolean;
        isLayoutRequired?: boolean;
        isLayoutValid?: boolean;
        isUserInteractionEnabled?: string | boolean;
        margin?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        marginBottom?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        marginLeft?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        marginRight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        marginTop?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        minHeight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        minWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        modal?: View;
        onAccessibilityHintChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onAccessibilityIdentifierChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onAccessibilityIgnoresInvertColorsChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onAccessibilityLabelChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onAccessibilityValueChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onAndroidBackPressed?: (args: import("@nativescript/core").EventData) => void;
        onColumnChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onColumnSpanChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onDockChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onDoubleTap?: (arg: import("@nativescript/core").TapGestureEventData) => any;
        onIosIgnoreSafeAreaChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIosOverflowSafeAreaChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIosOverflowSafeAreaEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIsEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIsUserInteractionEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onLeftChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onLoaded?: (args: import("@nativescript/core").EventData) => void;
        onLongPress?: (arg: import("@nativescript/core").GestureEventData) => any;
        onOriginXChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onOriginYChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onPan?: (arg: import("@nativescript/core").PanGestureEventData) => any;
        onPinch?: (arg: import("@nativescript/core").PinchGestureEventData) => any;
        onRotation?: (arg: import("@nativescript/core").RotationGestureEventData) => any;
        onRowChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onRowSpanChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onShowingModally?: (args: import("@nativescript/core").ShownModallyData) => void;
        onShownModally?: (args: import("@nativescript/core").ShownModallyData) => void;
        onLayoutChanged?: (args: import("@nativescript/core").EventData) => void;
        onSwipe?: (arg: import("@nativescript/core").SwipeGestureEventData) => any;
        onTap?: (arg: import("@nativescript/core").TapGestureEventData) => any;
        onTopChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onTouch?: (arg: import("@nativescript/core").TouchGestureEventData) => any;
        onUnloaded?: (args: import("@nativescript/core").EventData) => void;
        opacity?: NumberKey;
        originX?: NumberKey;
        originY?: NumberKey;
        perspective?: NumberKey;
        rotate?: NumberKey;
        rotateX?: NumberKey;
        rotateY?: NumberKey;
        scaleX?: NumberKey;
        scaleY?: NumberKey;
        textTransform?: "none" | "initial" | "capitalize" | "uppercase" | "lowercase";
        translateX?: NumberKey;
        translateY?: NumberKey;
        verticalAlignment?: "top" | "bottom" | "stretch" | "middle";
        visibility?: "hidden" | "visible" | "collapse" | "collapsed";
        width?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
        clipToBounds?: string | boolean;
        isPassThroughParentEnabled?: string | boolean;
        onClipToBoundsChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        onIsPassThroughParentEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
        padding?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        paddingBottom?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        paddingLeft?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        paddingRight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        paddingTop?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
        columns?: string;
        rows?: string;
    }, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)>) | (new (props: any) => React.Component<any, any, any>)>;
}
export declare const Pager: React.ForwardRefExoticComponent<{
    items: ItemsSource | any[];
    /** User may specify cellFactory for single-template or cellFactories for multi-template. */
    cellFactory?: CellFactory;
    cellFactories?: Map<string, {
        placeholderItem: any;
        cellFactory: CellFactory;
    }>;
    onSelectedIndexChange?(args: any): void;
    onSelectedIndexChanged?(args: any): void;
    scroll?(args: any): void;
    swipe?(args: any): void;
    swipeStart?(args: any): void;
    swipeOver?(args: any): void;
    swipeEnd?(args: any): void;
    onLoadMoreItems?: (args: any) => void;
    _debug?: {
        logLevel: "debug" | "info";
        onCellFirstLoad?: (container: CellViewContainer) => void;
        onCellRecycle?: (container: CellViewContainer) => void;
    };
} & Pick<PagerAttributes, "itemTemplate" | "itemTemplates" | "items" | "itemTemplateSelector" | "itemIdGenerator" | "left" | "top" | "indicatorColor" | "indicatorSelectedColor" | "indicator" | "selectedIndex" | "spacing" | "peaking" | "canGoRight" | "canGoLeft" | "orientation" | "disableSwipe" | "perPage" | "transformers" | "showIndicator" | "alignSelf" | "android" | "bindingContext" | "class" | "className" | "col" | "colSpan" | "column" | "columnSpan" | "cssClasses" | "cssPseudoClasses" | "dock" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "ios" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "row" | "rowSpan" | "typeName" | "viewController" | "accessibilityHidden" | "accessibilityHint" | "accessibilityIdentifier" | "accessibilityIgnoresInvertColors" | "accessibilityLabel" | "accessibilityLanguage" | "accessibilityLiveRegion" | "accessibilityMediaSession" | "accessibilityRole" | "accessibilityState" | "accessibilityValue" | "accessible" | "androidDynamicElevationOffset" | "androidElevation" | "automationText" | "background" | "backgroundColor" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomWidth" | "borderColor" | "borderLeftColor" | "borderLeftWidth" | "borderRadius" | "borderRightColor" | "borderRightWidth" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopWidth" | "borderWidth" | "boxShadow" | "color" | "css" | "cssType" | "height" | "horizontalAlignment" | "iosIgnoreSafeArea" | "iosOverflowSafeArea" | "iosOverflowSafeAreaEnabled" | "isEnabled" | "isLayoutRequired" | "isLayoutValid" | "isUserInteractionEnabled" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "minHeight" | "minWidth" | "modal" | "onAccessibilityHintChange" | "onAccessibilityIdentifierChange" | "onAccessibilityIgnoresInvertColorsChange" | "onAccessibilityLabelChange" | "onAccessibilityValueChange" | "onAndroidBackPressed" | "onColumnChange" | "onColumnSpanChange" | "onDockChange" | "onDoubleTap" | "onIosIgnoreSafeAreaChange" | "onIosOverflowSafeAreaChange" | "onIosOverflowSafeAreaEnabledChange" | "onIsEnabledChange" | "onIsUserInteractionEnabledChange" | "onLeftChange" | "onLoaded" | "onLongPress" | "onOriginXChange" | "onOriginYChange" | "onPan" | "onPinch" | "onRotation" | "onRowChange" | "onRowSpanChange" | "onShowingModally" | "onShownModally" | "onLayoutChanged" | "onSwipe" | "onTap" | "onTopChange" | "onTouch" | "onUnloaded" | "opacity" | "originX" | "originY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "scaleX" | "scaleY" | "textTransform" | "translateX" | "translateY" | "verticalAlignment" | "visibility" | "width" | "loadMoreCount"> & React.RefAttributes<NSVElement<NativeScriptPager>>>;
export declare const PagerItem: React.ForwardRefExoticComponent<Pick<Pick<Pick<Pick<Pick<Pick<import("react-nativescript/dist/lib/react-nativescript-jsx").ObservableAttributes, never> & {
    alignSelf?: "auto" | "stretch" | "flex-start" | "flex-end" | "center" | "baseline";
    android?: any;
    bindingContext?: any;
    class?: string;
    className?: string;
    col?: number;
    colSpan?: number;
    column?: number;
    columnSpan?: number;
    cssClasses?: Set<string>;
    cssPseudoClasses?: Set<string>;
    dock?: "left" | "top" | "right" | "bottom";
    domNode?: import("@nativescript/core/debugger/dom-node").DOMNode;
    effectiveBorderBottomWidth?: number;
    effectiveBorderLeftWidth?: number;
    effectiveBorderRightWidth?: number;
    effectiveBorderTopWidth?: number;
    effectiveHeight?: number;
    effectiveLeft?: number;
    effectiveMarginBottom?: number;
    effectiveMarginLeft?: number;
    effectiveMarginRight?: number;
    effectiveMarginTop?: number;
    effectiveMinHeight?: number;
    effectiveMinWidth?: number;
    effectivePaddingBottom?: number;
    effectivePaddingLeft?: number;
    effectivePaddingRight?: number;
    effectivePaddingTop?: number;
    effectiveTop?: number;
    effectiveWidth?: number;
    flexGrow?: number;
    flexShrink?: number;
    flexWrapBefore?: boolean;
    hidden?: string | boolean;
    id?: string;
    ios?: any;
    isCollapsed?: any;
    isLoaded?: boolean;
    left?: CoreTypes.LengthType;
    nativeView?: any;
    onBindingContextChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onClassNameChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onHiddenChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIdChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    order?: number;
    page?: import("@nativescript/core").Page;
    parent?: import("@nativescript/core").ViewBase;
    parentNode?: import("@nativescript/core").ViewBase;
    recycleNativeView?: "auto" | "always" | "never";
    reusable?: boolean;
    row?: number;
    rowSpan?: number;
    top?: CoreTypes.LengthType;
    typeName?: string;
    viewController?: any;
}, "alignSelf" | "class" | "className" | "col" | "colSpan" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "typeName" | "viewController"> & {
    accessibilityHidden?: string | boolean;
    accessibilityHint?: string;
    accessibilityIdentifier?: string;
    accessibilityIgnoresInvertColors?: string | boolean;
    accessibilityLabel?: string;
    accessibilityLanguage?: string;
    accessibilityLiveRegion?: import("@nativescript/core").AccessibilityLiveRegion;
    accessibilityMediaSession?: string | boolean;
    accessibilityRole?: import("@nativescript/core").AccessibilityRole;
    accessibilityState?: import("@nativescript/core").AccessibilityState;
    accessibilityValue?: string;
    accessible?: string | boolean;
    android?: any;
    androidDynamicElevationOffset?: NumberKey;
    androidElevation?: NumberKey;
    automationText?: string;
    background?: string;
    backgroundColor?: string | Color;
    backgroundImage?: string | import("@nativescript/core/ui/styling/gradient").LinearGradient;
    backgroundPosition?: string;
    backgroundRepeat?: "repeat" | "repeat-x" | "repeat-y" | "no-repeat";
    backgroundSize?: string;
    bindingContext?: any;
    borderBottomColor?: string | Color;
    borderBottomLeftRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderBottomRightRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderBottomWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderColor?: string | Color;
    borderLeftColor?: string | Color;
    borderLeftWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderRightColor?: string | Color;
    borderRightWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderTopColor?: string | Color;
    borderTopLeftRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderTopRightRadius?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderTopWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    borderWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    boxShadow?: string | import("@nativescript/core/ui/styling/css-shadow").CSSShadow;
    color?: string | Color;
    column?: NumberKey;
    columnSpan?: NumberKey;
    css?: string;
    cssClasses?: Set<string>;
    cssPseudoClasses?: Set<string>;
    cssType?: string;
    dock?: "left" | "top" | "right" | "bottom";
    height?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    horizontalAlignment?: "left" | "right" | "stretch" | "center";
    ios?: any;
    iosIgnoreSafeArea?: string | boolean;
    iosOverflowSafeArea?: string | boolean;
    iosOverflowSafeAreaEnabled?: string | boolean;
    isEnabled?: string | boolean;
    isLayoutRequired?: boolean;
    isLayoutValid?: boolean;
    isUserInteractionEnabled?: string | boolean;
    left?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    margin?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    marginBottom?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    marginLeft?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    marginRight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    marginTop?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
    minHeight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    minWidth?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    modal?: View;
    onAccessibilityHintChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onAccessibilityIdentifierChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onAccessibilityIgnoresInvertColorsChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onAccessibilityLabelChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onAccessibilityValueChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onAndroidBackPressed?: (args: import("@nativescript/core").EventData) => void;
    onColumnChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onColumnSpanChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onDockChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onDoubleTap?: (arg: import("@nativescript/core").TapGestureEventData) => any;
    onIosIgnoreSafeAreaChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIosOverflowSafeAreaChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIosOverflowSafeAreaEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIsEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIsUserInteractionEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onLeftChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onLoaded?: (args: import("@nativescript/core").EventData) => void;
    onLongPress?: (arg: import("@nativescript/core").GestureEventData) => any;
    onOriginXChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onOriginYChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onPan?: (arg: import("@nativescript/core").PanGestureEventData) => any;
    onPinch?: (arg: import("@nativescript/core").PinchGestureEventData) => any;
    onRotation?: (arg: import("@nativescript/core").RotationGestureEventData) => any;
    onRowChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onRowSpanChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onShowingModally?: (args: import("@nativescript/core").ShownModallyData) => void;
    onShownModally?: (args: import("@nativescript/core").ShownModallyData) => void;
    onLayoutChanged?: (args: import("@nativescript/core").EventData) => void;
    onSwipe?: (arg: import("@nativescript/core").SwipeGestureEventData) => any;
    onTap?: (arg: import("@nativescript/core").TapGestureEventData) => any;
    onTopChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onTouch?: (arg: import("@nativescript/core").TouchGestureEventData) => any;
    onUnloaded?: (args: import("@nativescript/core").EventData) => void;
    opacity?: NumberKey;
    originX?: NumberKey;
    originY?: NumberKey;
    perspective?: NumberKey;
    rotate?: NumberKey;
    rotateX?: NumberKey;
    rotateY?: NumberKey;
    row?: NumberKey;
    rowSpan?: NumberKey;
    scaleX?: NumberKey;
    scaleY?: NumberKey;
    textTransform?: "none" | "initial" | "capitalize" | "uppercase" | "lowercase";
    top?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    translateX?: NumberKey;
    translateY?: NumberKey;
    verticalAlignment?: "top" | "bottom" | "stretch" | "middle";
    visibility?: "hidden" | "visible" | "collapse" | "collapsed";
    width?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit | CoreTypes.LengthPercentUnit;
}, "left" | "top" | "alignSelf" | "android" | "bindingContext" | "class" | "className" | "col" | "colSpan" | "column" | "columnSpan" | "cssClasses" | "cssPseudoClasses" | "dock" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "ios" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "row" | "rowSpan" | "typeName" | "viewController" | "accessibilityHidden" | "accessibilityHint" | "accessibilityIdentifier" | "accessibilityIgnoresInvertColors" | "accessibilityLabel" | "accessibilityLanguage" | "accessibilityLiveRegion" | "accessibilityMediaSession" | "accessibilityRole" | "accessibilityState" | "accessibilityValue" | "accessible" | "androidDynamicElevationOffset" | "androidElevation" | "automationText" | "background" | "backgroundColor" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomWidth" | "borderColor" | "borderLeftColor" | "borderLeftWidth" | "borderRadius" | "borderRightColor" | "borderRightWidth" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopWidth" | "borderWidth" | "boxShadow" | "color" | "css" | "cssType" | "height" | "horizontalAlignment" | "iosIgnoreSafeArea" | "iosOverflowSafeAreaEnabled" | "isEnabled" | "isLayoutRequired" | "isLayoutValid" | "isUserInteractionEnabled" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "minHeight" | "minWidth" | "modal" | "onAccessibilityHintChange" | "onAccessibilityIdentifierChange" | "onAccessibilityIgnoresInvertColorsChange" | "onAccessibilityLabelChange" | "onAccessibilityValueChange" | "onAndroidBackPressed" | "onColumnChange" | "onColumnSpanChange" | "onDockChange" | "onDoubleTap" | "onIosIgnoreSafeAreaChange" | "onIosOverflowSafeAreaChange" | "onIosOverflowSafeAreaEnabledChange" | "onIsEnabledChange" | "onIsUserInteractionEnabledChange" | "onLeftChange" | "onLoaded" | "onLongPress" | "onOriginXChange" | "onOriginYChange" | "onPan" | "onPinch" | "onRotation" | "onRowChange" | "onRowSpanChange" | "onShowingModally" | "onShownModally" | "onLayoutChanged" | "onSwipe" | "onTap" | "onTopChange" | "onTouch" | "onUnloaded" | "opacity" | "originX" | "originY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "scaleX" | "scaleY" | "textTransform" | "translateX" | "translateY" | "verticalAlignment" | "visibility" | "width"> & {
    iosOverflowSafeArea?: boolean;
}, "left" | "top" | "alignSelf" | "android" | "bindingContext" | "class" | "className" | "col" | "colSpan" | "column" | "columnSpan" | "cssClasses" | "cssPseudoClasses" | "dock" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "ios" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "row" | "rowSpan" | "typeName" | "viewController" | "accessibilityHidden" | "accessibilityHint" | "accessibilityIdentifier" | "accessibilityIgnoresInvertColors" | "accessibilityLabel" | "accessibilityLanguage" | "accessibilityLiveRegion" | "accessibilityMediaSession" | "accessibilityRole" | "accessibilityState" | "accessibilityValue" | "accessible" | "androidDynamicElevationOffset" | "androidElevation" | "automationText" | "background" | "backgroundColor" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomWidth" | "borderColor" | "borderLeftColor" | "borderLeftWidth" | "borderRadius" | "borderRightColor" | "borderRightWidth" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopWidth" | "borderWidth" | "boxShadow" | "color" | "css" | "cssType" | "height" | "horizontalAlignment" | "iosIgnoreSafeArea" | "iosOverflowSafeArea" | "iosOverflowSafeAreaEnabled" | "isEnabled" | "isLayoutRequired" | "isLayoutValid" | "isUserInteractionEnabled" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "minHeight" | "minWidth" | "modal" | "onAccessibilityHintChange" | "onAccessibilityIdentifierChange" | "onAccessibilityIgnoresInvertColorsChange" | "onAccessibilityLabelChange" | "onAccessibilityValueChange" | "onAndroidBackPressed" | "onColumnChange" | "onColumnSpanChange" | "onDockChange" | "onDoubleTap" | "onIosIgnoreSafeAreaChange" | "onIosOverflowSafeAreaChange" | "onIosOverflowSafeAreaEnabledChange" | "onIsEnabledChange" | "onIsUserInteractionEnabledChange" | "onLeftChange" | "onLoaded" | "onLongPress" | "onOriginXChange" | "onOriginYChange" | "onPan" | "onPinch" | "onRotation" | "onRowChange" | "onRowSpanChange" | "onShowingModally" | "onShownModally" | "onLayoutChanged" | "onSwipe" | "onTap" | "onTopChange" | "onTouch" | "onUnloaded" | "opacity" | "originX" | "originY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "scaleX" | "scaleY" | "textTransform" | "translateX" | "translateY" | "verticalAlignment" | "visibility" | "width">, "left" | "top" | "alignSelf" | "android" | "bindingContext" | "class" | "className" | "col" | "colSpan" | "column" | "columnSpan" | "cssClasses" | "cssPseudoClasses" | "dock" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "ios" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "row" | "rowSpan" | "typeName" | "viewController" | "accessibilityHidden" | "accessibilityHint" | "accessibilityIdentifier" | "accessibilityIgnoresInvertColors" | "accessibilityLabel" | "accessibilityLanguage" | "accessibilityLiveRegion" | "accessibilityMediaSession" | "accessibilityRole" | "accessibilityState" | "accessibilityValue" | "accessible" | "androidDynamicElevationOffset" | "androidElevation" | "automationText" | "background" | "backgroundColor" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomWidth" | "borderColor" | "borderLeftColor" | "borderLeftWidth" | "borderRadius" | "borderRightColor" | "borderRightWidth" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopWidth" | "borderWidth" | "boxShadow" | "color" | "css" | "cssType" | "height" | "horizontalAlignment" | "iosIgnoreSafeArea" | "iosOverflowSafeArea" | "iosOverflowSafeAreaEnabled" | "isEnabled" | "isLayoutRequired" | "isLayoutValid" | "isUserInteractionEnabled" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "minHeight" | "minWidth" | "modal" | "onAccessibilityHintChange" | "onAccessibilityIdentifierChange" | "onAccessibilityIgnoresInvertColorsChange" | "onAccessibilityLabelChange" | "onAccessibilityValueChange" | "onAndroidBackPressed" | "onColumnChange" | "onColumnSpanChange" | "onDockChange" | "onDoubleTap" | "onIosIgnoreSafeAreaChange" | "onIosOverflowSafeAreaChange" | "onIosOverflowSafeAreaEnabledChange" | "onIsEnabledChange" | "onIsUserInteractionEnabledChange" | "onLeftChange" | "onLoaded" | "onLongPress" | "onOriginXChange" | "onOriginYChange" | "onPan" | "onPinch" | "onRotation" | "onRowChange" | "onRowSpanChange" | "onShowingModally" | "onShownModally" | "onLayoutChanged" | "onSwipe" | "onTap" | "onTopChange" | "onTouch" | "onUnloaded" | "opacity" | "originX" | "originY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "scaleX" | "scaleY" | "textTransform" | "translateX" | "translateY" | "verticalAlignment" | "visibility" | "width"> & {
    clipToBounds?: string | boolean;
    isPassThroughParentEnabled?: string | boolean;
    onClipToBoundsChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    onIsPassThroughParentEnabledChange?: (args: import("@nativescript/core").PropertyChangeData) => void;
    padding?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    paddingBottom?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    paddingLeft?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    paddingRight?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
    paddingTop?: string | number | CoreTypes.LengthDipUnit | CoreTypes.LengthPxUnit;
}, "left" | "top" | "alignSelf" | "android" | "bindingContext" | "class" | "className" | "col" | "colSpan" | "column" | "columnSpan" | "cssClasses" | "cssPseudoClasses" | "dock" | "domNode" | "effectiveBorderBottomWidth" | "effectiveBorderLeftWidth" | "effectiveBorderRightWidth" | "effectiveBorderTopWidth" | "effectiveHeight" | "effectiveLeft" | "effectiveMarginBottom" | "effectiveMarginLeft" | "effectiveMarginRight" | "effectiveMarginTop" | "effectiveMinHeight" | "effectiveMinWidth" | "effectivePaddingBottom" | "effectivePaddingLeft" | "effectivePaddingRight" | "effectivePaddingTop" | "effectiveTop" | "effectiveWidth" | "flexGrow" | "flexShrink" | "flexWrapBefore" | "hidden" | "id" | "ios" | "isCollapsed" | "isLoaded" | "nativeView" | "onBindingContextChange" | "onClassNameChange" | "onHiddenChange" | "onIdChange" | "order" | "page" | "parent" | "parentNode" | "recycleNativeView" | "reusable" | "row" | "rowSpan" | "typeName" | "viewController" | "accessibilityHidden" | "accessibilityHint" | "accessibilityIdentifier" | "accessibilityIgnoresInvertColors" | "accessibilityLabel" | "accessibilityLanguage" | "accessibilityLiveRegion" | "accessibilityMediaSession" | "accessibilityRole" | "accessibilityState" | "accessibilityValue" | "accessible" | "androidDynamicElevationOffset" | "androidElevation" | "automationText" | "background" | "backgroundColor" | "backgroundImage" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomWidth" | "borderColor" | "borderLeftColor" | "borderLeftWidth" | "borderRadius" | "borderRightColor" | "borderRightWidth" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopWidth" | "borderWidth" | "boxShadow" | "color" | "css" | "cssType" | "height" | "horizontalAlignment" | "iosIgnoreSafeArea" | "iosOverflowSafeArea" | "iosOverflowSafeAreaEnabled" | "isEnabled" | "isLayoutRequired" | "isLayoutValid" | "isUserInteractionEnabled" | "margin" | "marginBottom" | "marginLeft" | "marginRight" | "marginTop" | "minHeight" | "minWidth" | "modal" | "onAccessibilityHintChange" | "onAccessibilityIdentifierChange" | "onAccessibilityIgnoresInvertColorsChange" | "onAccessibilityLabelChange" | "onAccessibilityValueChange" | "onAndroidBackPressed" | "onColumnChange" | "onColumnSpanChange" | "onDockChange" | "onDoubleTap" | "onIosIgnoreSafeAreaChange" | "onIosOverflowSafeAreaChange" | "onIosOverflowSafeAreaEnabledChange" | "onIsEnabledChange" | "onIsUserInteractionEnabledChange" | "onLeftChange" | "onLoaded" | "onLongPress" | "onOriginXChange" | "onOriginYChange" | "onPan" | "onPinch" | "onRotation" | "onRowChange" | "onRowSpanChange" | "onShowingModally" | "onShownModally" | "onLayoutChanged" | "onSwipe" | "onTap" | "onTopChange" | "onTouch" | "onUnloaded" | "opacity" | "originX" | "originY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "scaleX" | "scaleY" | "textTransform" | "translateX" | "translateY" | "verticalAlignment" | "visibility" | "width" | "clipToBounds" | "isPassThroughParentEnabled" | "onClipToBoundsChange" | "onIsPassThroughParentEnabledChange" | "padding" | "paddingBottom" | "paddingLeft" | "paddingRight" | "paddingTop"> & {
    columns?: string;
    rows?: string;
} & {
    forwardedRef?: React.RefObject<NSVElement<NativeScriptPagerItem>>;
} & React.RefAttributes<NSVElement<NativeScriptPagerItem>>>;
declare global {
    module JSX {
        interface IntrinsicElements {
            pager: NativeScriptProps<PagerAttributes, NativeScriptPager>;
            pagerItem: NativeScriptProps<PagerItemAttributes, NativeScriptPagerItem>;
        }
    }
}
export {};
